Struct MoveToPreviousLine
pub struct MoveToPreviousLine(pub u16);Available on crate feature
term only.Expand description
A command that moves the terminal cursor up the given number of lines, and moves it to the first column.
Notes
- This command is 1 based, meaning
MoveToPreviousLine(1)moves to the previous line. - Most terminals default 0 argument to 1.
- Commands must be executed/queued for execution otherwise they do nothing.
Tuple Fields
0: u16Trait Implementations
impl Clone for MoveToPreviousLine
impl Clone for MoveToPreviousLine
fn clone(&self) -> MoveToPreviousLine
fn clone(&self) -> MoveToPreviousLine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Command for MoveToPreviousLine
impl Command for MoveToPreviousLine
impl Copy for MoveToPreviousLine
impl Debug for MoveToPreviousLine
impl Debug for MoveToPreviousLine
impl Display for MoveToPreviousLine
impl Display for MoveToPreviousLine
impl Eq for MoveToPreviousLine
impl PartialEq for MoveToPreviousLine
impl PartialEq for MoveToPreviousLine
impl StructuralPartialEq for MoveToPreviousLine